Tween class

Constructors

Tween(dynamic _object, [TweenGroup? group])

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

chain() → Tween
delay([int amount = 0]) → Tween
dispose() → void
duration([int duration = 1000]) → Tween
dynamicF([bool isDynamic = false]) → Tween
easing([num easingFunction(num, [num?])?]) → Tween
end() → Tween
getDuration() → num
getId() → int
group([TweenGroup? group]) → Tween
interpolation([num interpolationFunction(List, num)?]) → Tween
isPaused() → bool
isPlaying() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onComplete(dynamic callback) → Tween
onEveryStart(dynamic callback) → Tween
onRepeat(dynamic callback) → Tween
onStart(dynamic callback) → Tween
onStop(dynamic callback) → Tween
onUpdate(dynamic callback) → Tween
pause([int? time]) → Tween
repeat([int times = 0]) → Tween
repeatDelay(dynamic amount) → Tween
resume([int? time]) → Tween
start([int? time, bool overrideStartingValues = false]) → Tween
startFromCurrentValues([int? time]) → Tween
stop() → Tween
stopChainedTweens() → Tween
to(Map target, [int duration = 1000]) → Tween
toString() → String
A string representation of this object.
inherited
update([int? time, bool autoStart = true]) → bool
@returns true if the tween is still playing after the update, false otherwise (calling update on a paused tween still returns true because it is still playing, just paused).
yoyo([bool yoyo = false]) → Tween

Operators

operator ==(Object other) → bool
The equality operator.
inherited