Utils class

Constructors

Utils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

bernstein(int n, int i) → num
catmullRom(num p0, num p1, num p2, num p3, num t) → num
factorial(int n) → dynamic
linear(num p0, num p1, num t) → num