DDSLoader class

Inheritance

Constructors

DDSLoader({LoadingManager? manager, bool flipY = false})

Properties

crossOrigin ↔ String
getter/setter pairinherited
flipY ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
images ↔ List
getter/setter pairinherited
loaded ↔ int
getter/setter pairinherited
manager ↔ LoadingManager
getter/setter pairinherited
mimeType ↔ String
getter/setter pairinherited
path ↔ String
getter/setter pairinherited
requestHeader ↔ Map<String, dynamic>
getter/setter pairinherited
resourcePath ↔ String?
getter/setter pairinherited
responseType ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texture → CompressedTexture
finalinherited
withCredentials ↔ bool
getter/setter pairinherited

Methods

dispose() → void
inherited
fromAsset(String asset, {String? package}) → Future<CompressedTexture?>
asset - path of the file to be loaded
inherited
fromBlob(Blob blob) → Future<CompressedTexture?>
blob - a blob of the file to be loaded
inherited
fromBytes(Uint8List bytes) → Future<CompressedTexture?>
bytes - the loaded bytes of the file
inherited
fromFile(File file) → Future<CompressedTexture?>
file - the file to be loaded
inherited
fromNetwork(Uri uri) → Future<CompressedTexture?>
uri - a uri containing the location of the file to be loaded
inherited
fromPath(String filePath) → Future<CompressedTexture?>
filePath - path of the file to be loaded
inherited
loadTexture(int i, Uint8List buffer) → Future<Texture?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(ByteBuffer buffer, bool loadMipmaps) → DDSInfo
  • Parses the given S3TC texture data. *
    • @param {ArrayBuffer} buffer - The raw texture data.
    • @param {boolean} loadMipmaps - Whether to load mipmaps or not.
    • @return {CompressedTextureLoader~TexData} An object representing the parsed texture data.
  • override
    setCrossOrigin(String crossOrigin) → CompressedTextureLoader
    crossOrigin — The crossOrigin string to implement CORS for loading the url from a different domain that allows CORS.
    inherited
    setPath(String path) → CompressedTextureLoader
    path — Set the base path for the asset.
    inherited
    setRequestHeader(Map<String, dynamic> requestHeader) → CompressedTextureLoader
    requestHeader - key: The name of the header whose value is to be set. value: The value to set as the body of the header.
    inherited
    setResourcePath(String? resourcePath) → CompressedTextureLoader
    resourcePath — Set the base path for dependent resources like textures.
    inherited
    setWithCredentials(bool value) → CompressedTextureLoader
    Whether the XMLHttpRequest uses credentials such as cookies, authorization headers or TLS client certificates. See XMLHttpRequest.withCredentials.
    inherited
    toString() → String
    A string representation of this object.
    inherited
    unknown(dynamic url) → Future<CompressedTexture?>
    If the type of format is unknown load it here.
    inherited

    Operators

    operator ==(Object other) → bool
    The equality operator.
    inherited