CompressedTextureLoader class

Class for loading a texture. This uses the ImageLoader internally for loading files.

final texture = await TextureLoader().fromAsset('textures/land_ocean_ice_cloud_2048.jpg' ); 
// immediately use the texture for material creation 

final material = MeshBasicMaterial({ MaterialProperty.map:texture});
Inheritance
  • Object
  • Loader
  • CompressedTextureLoader
Implementers

Constructors

CompressedTextureLoader([LoadingManager? manager])

Properties

crossOrigin ↔ String
getter/setter pairinherited
flipY ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
images ↔ List
getter/setter pair
loaded ↔ int
getter/setter pair
manager ↔ LoadingManager
getter/setter pairinherited
mimeType ↔ String
getter/setter pairinherited
path ↔ String
getter/setter pairinherited
requestHeader ↔ Map<String, dynamic>
getter/setter pairinherited
resourcePath ↔ String?
getter/setter pairinherited
responseType ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texture → CompressedTexture
final
withCredentials ↔ bool
getter/setter pairinherited

Methods

dispose() → void
override
fromAsset(String asset, {String? package}) → Future<CompressedTexture?>
asset - path of the file to be loaded
override
fromBlob(Blob blob) → Future<CompressedTexture?>
blob - a blob of the file to be loaded
override
fromBytes(Uint8List bytes) → Future<CompressedTexture?>
bytes - the loaded bytes of the file
override
fromFile(File file) → Future<CompressedTexture?>
file - the file to be loaded
override
fromNetwork(Uri uri) → Future<CompressedTexture?>
uri - a uri containing the location of the file to be loaded
override
fromPath(String filePath) → Future<CompressedTexture?>
filePath - path of the file to be loaded
override
loadTexture(int i, Uint8List buffer) → Future<Texture?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(ByteBuffer buffer, bool loadMipmaps) → dynamic
setCrossOrigin(String crossOrigin) → CompressedTextureLoader
crossOrigin — The crossOrigin string to implement CORS for loading the url from a different domain that allows CORS.
override
setPath(String path) → CompressedTextureLoader
path — Set the base path for the asset.
override
setRequestHeader(Map<String, dynamic> requestHeader) → CompressedTextureLoader
requestHeader - key: The name of the header whose value is to be set. value: The value to set as the body of the header.
override
setResourcePath(String? resourcePath) → CompressedTextureLoader
resourcePath — Set the base path for dependent resources like textures.
override
setWithCredentials(bool value) → CompressedTextureLoader
Whether the XMLHttpRequest uses credentials such as cookies, authorization headers or TLS client certificates. See XMLHttpRequest.withCredentials.
override
toString() → String
A string representation of this object.
inherited
unknown(dynamic url) → Future<CompressedTexture?>
If the type of format is unknown load it here.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited