TextureLoaderData class

Constructors

TextureLoaderData({num? width, num? height, dynamic data, required int type, int? format, num? gamma, num? exposure, String? header, int? mipmapCount, bool? generateMipmaps, bool? flipY, String? colorSpace, int anisotropy = 1, int? minFilter = LinearFilter, int? magFilter = LinearFilter, int? wrapS = ClampToEdgeWrapping, int? wrapT = ClampToEdgeWrapping, dynamic image})

Properties

anisotropy ↔ int
getter/setter pair
colorSpace ↔ String?
getter/setter pair
data ↔ dynamic
getter/setter pair
exposure ↔ num?
getter/setter pair
flipY ↔ bool?
getter/setter pair
format ↔ int?
getter/setter pair
gamma ↔ num?
getter/setter pair
generateMipmaps ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
height ↔ num?
getter/setter pair
image ↔ dynamic
getter/setter pair
json → Map<String, dynamic>
no setter
magFilter ↔ int?
getter/setter pair
minFilter ↔ int?
getter/setter pair
mipmapCount ↔ int?
getter/setter pair
mipmaps ↔ List?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ int
getter/setter pair
width ↔ num?
getter/setter pair
wrapS ↔ int?
getter/setter pair
wrapT ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDataTexture() → DataTexture
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited